summaryrefslogtreecommitdiff
path: root/libview/ev-stock-icons.c
diff options
context:
space:
mode:
Diffstat (limited to 'libview/ev-stock-icons.c')
-rw-r--r--libview/ev-stock-icons.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/libview/ev-stock-icons.c b/libview/ev-stock-icons.c
index 47b3943e..7d86fd98 100644
--- a/libview/ev-stock-icons.c
+++ b/libview/ev-stock-icons.c
@@ -1,17 +1,17 @@
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* Stock icons for Evince
*
* Copyright (C) 2003 Martin Kretzschmar
*
* Author:
* Martin Kretzschmar <[email protected]>
*
* Evince is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* Evince is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
* License for more details.
@@ -32,7 +32,7 @@ typedef struct {
char *icon;
} EvStockIcon;
/* Evince stock icons */
static const EvStockIcon stock_icons [] = {
{ EV_STOCK_ZOOM, "zoom" },
{ EV_STOCK_ZOOM_PAGE, "zoom-fit-height" },
@@ -65,7 +65,7 @@ ev_stock_icons_add_icons_path_for_screen (GdkScreen *screen)
gint n_paths;
gint i;
/* GtkIconTheme will then look in Evince custom hicolor dir
* for icons as well as the standard search paths
*/
gtk_icon_theme_get_search_path (icon_theme, &path, &n_paths);
@@ -97,10 +97,10 @@ ev_stock_icons_init (void)
gchar *dir;
dir = g_win32_get_package_installation_directory_of_module (NULL);
- ev_icons_path = g_build_filename (dir, "share", "evince", "icons", NULL);
+ ev_icons_path = g_build_filename (dir, "share", "atril", "icons", NULL);
g_free (dir);
#else
- ev_icons_path = g_build_filename (EVINCEDATADIR, "icons", NULL);
+ ev_icons_path = g_build_filename (ATRILDATADIR, "icons", NULL);
#endif
factory = gtk_icon_factory_new ();
@@ -1,17 +1,17 @@
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* Stock icons for Evince
+/* Stock icons for Atril
*
* Copyright (C) 2003 Martin Kretzschmar
@@ -1,17 +1,17 @@
* Martin Kretzschmar <[email protected]>
*
- * Evince is free software; you can redistribute it and/or modify it
+ * Atril is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -1,17 +1,17 @@
* (at your option) any later version.
*
- * Evince is distributed in the hope that it will be useful, but WITHOUT
+ * Atril is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
* or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
@@ -32,7 +32,7 @@ typedef struct {
char *icon;
} EvStockIcon;
-/* Evince stock icons */
+/* Atril stock icons */
static const EvStockIcon stock_icons [] = {
{ EV_STOCK_ZOOM, "zoom" },
@@ -65,7 +65,7 @@ ev_stock_icons_add_icons_path_for_screen (GdkScreen *screen)
gint n_paths;
gint i;
- /* GtkIconTheme will then look in Evince custom hicolor dir
+ /* GtkIconTheme will then look in Atril custom hicolor dir
* for icons as well as the standard search paths
*/